#!/bin/sh
# Simple script to start GeoGebra

if [ -z "$JAVACMD" ] ; then
	JAVACMD=java
fi

exec $JAVACMD -Xms32m -Xmx512m $JAVA_OPTS -jar /usr/share/geogebra/geogebra.jar "$@"
	

